var documenterSearchIndex = {"docs":
[{"location":"#NotebookToLatex.jl","page":"Home","title":"NotebookToLatex.jl","text":"","category":"section"},{"location":"#Why-this-Package?","page":"Home","title":"Why this Package?","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"This package converts your notebook files (Pluto or Jupyter) to beautiful and simple Latex files, that are easy to modify. Thus, making it ideal to write reports, articles or books from notebooks.","category":"page"},{"location":"","page":"Home","title":"Home","text":"Although it's already possible to convert both Pluto and Jupyter notebooks to PDFs, or even to Latex (via Pandoc), the PDFs are not very customizable and the Latex files are usually very messy. In contrast, NotebookToLatex.jl focuses less in generality, and more on opinionated defaults.","category":"page"},{"location":"","page":"Home","title":"Home","text":"The package has it's own implementation to parse Markdown to Latex, e.g. it turns # Example to \\chapter{Example}. Thus, one can dive down into the actual Julia code and customize it for his own preference. Or, submit an issue requesting the feature. Hopefully, more and more customization will be possible from the get go as the package evolves.","category":"page"},{"location":"","page":"Home","title":"Home","text":"Another very important point to note is that NotebookToLatex.jl uses julia-mono-listing. This enables it to produce beautiful Julia code inside the Latex pdf. Note that it requires using lualatex for compilation.","category":"page"},{"location":"#Getting-Started","page":"Home","title":"Getting Started","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"This package is very simple to use. There is pretty much just one function to be used, i.e.","category":"page"},{"location":"","page":"Home","title":"Home","text":"notebooktolatex","category":"page"},{"location":"#NotebookToLatex.notebooktolatex","page":"Home","title":"NotebookToLatex.notebooktolatex","text":"notebooktolatex(notebook, targetdir=\"./build_latex\"; template=:book, fontpath=nothing)\n\nTakes a notebook file, converts it to Latex and creates a file structure with figures, fonts and listing files.\n\ntargetdir is the target directory where the Latex project will be created.\n\nIf the directory does no exists, it is created.\n\ntemplate - The template for the Latex file. It's based on Latex templates.\n\nCurrent supported templates are :book, :mathbook.\n\nfontpath - The output Latex files uses JuliaMono fonts in order to support the\n\nunicodes that are also supported in Julia. If the user already has JuliaMono installed, he can provide the path to where the .ttf files are stored. If nothing is passed, then the font files will be downloaded and saved in the ./fonts/ folder.\n\n\n\n\n\n","category":"function"},{"location":"#Basic-Use","page":"Home","title":"Basic Use","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"To convert the notebooks just use notebooktolatex(\"mynotebook.jl\", template=:book). This will produce a directory ./build_latex/ where the Latex files will be generated. Inside build_latex/ you will have:","category":"page"},{"location":"","page":"Home","title":"Home","text":"build_latex\n│   main.tex\n│   julia_font.tex\n│   julia_listings.tex\n│   julia_listings_unicode.tex\n│   preface.tex\n│\n└───figures\n│   │   mynotebook_plot1.png\n│   └───mynotebook_plot2.png\n└───fonts\n│   │   JuliaMono_Regular.ttf\n│   │   ...\n│   \n└───frontmatter\n│   │   titlepage.tex\n│   └───copyright.tex\n│\n└───notebooks\n    └───mynotebook.tex","category":"page"},{"location":"","page":"Home","title":"Home","text":"Using template=:book, we get the Latex book format, thus, we have a preface.tex, a titlepage.tex and a copyright.tex page. The notebook will be included as a chapter. To get your final book pdf, just compile the main.tex using lualatex.","category":"page"},{"location":"","page":"Home","title":"Home","text":"In case you want a different project folder, you can run the command with an extra argument providing the target directory for the Latex files, e.g.:","category":"page"},{"location":"","page":"Home","title":"Home","text":"`notebooktolatex(\"mynotebook.jl\", \"./project/\",template=:book)`.","category":"page"},{"location":"","page":"Home","title":"Home","text":"This will create a ./project/ folder instead of the ./build_latex.","category":"page"},{"location":"#Font-JuliaMono","page":"Home","title":"Font - JuliaMono","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"Note that when you run notebooktolatex without providing a fontpath, this will install the .ttf files in the project directory. You might instead run the command with the path to the folder containing the JuliaMono fonts (at the moment, the package requires this specific font in order to properly deal with unicode symbols). Here is an example:","category":"page"},{"location":"","page":"Home","title":"Home","text":"notebooktolatex(\"mynotebook.jl\", template=:book,\n        fontpath=\"/home/davibarreira/.local/share/fonts/Unknown Vendor/TrueType/JuliaMono/\")","category":"page"},{"location":"","page":"Home","title":"Home","text":"Note that I've used /home/username instead of ~/. This is necessary for Latex to correctly find your fonts. You can also do this manually by changing the julia_font.tex file.","category":"page"},{"location":"#Templates","page":"Home","title":"Templates","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"At the moment, the available templates are:","category":"page"},{"location":"","page":"Home","title":"Home","text":":book - The standard Latex book template;\n:mathbook - Very similar to :book, but with some extra packages already imported.","category":"page"},{"location":"#Workflow","page":"Home","title":"Workflow","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"Once the Latex files are generated, you can modify your notebooks and run the notebooktolatex command again. This will only modify the notebook Latex file and the figures, while all the other Latex files will stay fixed. If you run the command for a new notebook, it won't overwrite your current files, it will only add an include{newnotebook} to the main.tex. Hence, you can convert each notebook one at a time.","category":"page"},{"location":"#Jupyter-Vs.-Pluto","page":"Home","title":"Jupyter Vs. Pluto","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"Jupyter notebooks store the outputs in the notebook file, while Pluto notebooks are simple Julia scripts. Hence, when converting notebooks, the Jupyter notebooks will be faster (way faster) to convert, since for the Pluto notebook, the converter will have to run the actual notebook. Thus, if you intend to constantly modify and convert your Pluto notebooks, it's advised to have a REPL (or a notebook!)  with Julia running constantly, in order to avoid precompiling every time. After converting the Pluto notebook the first time, the next time should be quite fast.","category":"page"},{"location":"#How-this-Package-Works","page":"Home","title":"How this Package Works","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"If you want to contribute to this package or if you want to modify it for your own use, this section is relevant. Here is a brief description of this package inner working. At this moment, the src/ contains five main Julia files:","category":"page"},{"location":"","page":"Home","title":"Home","text":"templates.jl - Contains the main.tex, preface.tex, and other .tex files templates.","category":"page"},{"location":"","page":"Home","title":"Home","text":"If you want to alter the current template, you can just modify this script. Note that there are some important lines that should be modified with care. For example,","category":"page"}]
}
